---
title: 'So You Want to Install Linux?'
author: 'Paul "Failure" Nijjar'
date: 2022-03-07
theme: Boadilla
width: 1400
colorlinks: true
linkcolor: blue
urlcolor: blue
---

# Hello

## Why This Presentation?

Suggestions from Shaun Browne: 

- What computers/platforms are well-suited for installing Linux?
- What distros are best suited to different niches?
- What are the differences between 32/64 bit computing?

. . .

More topic suggestions: <https://kwlug.org/node/1269>

(You can make a suggestion too!) 

. . .

(You can give a presentation, too!)


## Who is this guy?

The one that sends the meeting announcements.

- My computers are used/hand-me-downs running Linux
- [Computer
  Recycling](https://www.theworkingcentre.org/computer-recycling/178) at The Working Centre
  + Anybody remember Laptop Rescue Missions?
- Presented a [custom linux distro](http://wclp.sourceforge.net) back
  in Aug 2004 (!?)
- Been supporting end users with Linux for a long time (too long?)


## Disclaimers

- I am not an expert. 
- I am a dinosaur.
- I prefer easy, practical solutions.
- This presentation is directed towards genuine beginners.
- This presentation is opinionated and not comprehensive.
- This presentation is made of bullet points, as if it was 1998.

## Goals

- Provide **nouns** to get you started

- Inspire others to give beginner-friendly presentations
  + Explicitly say the obvious things

- Clarify confusing things 

- Crowdsource best practices

# Considerations

## Why are you doing this?

::: incremental

- Nostalgia for old hardware?
- Bragging rights?
- Learn skills?
- Use a specific tool? 
- Make a server?
- Revitalize an old computer?
- Give a friend/family member a computer?

:::

## Why are you doing this?

- **Nostalgia?** Emulators? Look for community. 
- **Bragging rights?** Go nuts, but don't expect it to be easy.
- **Learn skills?** Virtual installs, bare metal installs
- **Use a specific tool?** Cross-platform build, virtualize,
well-supported distros
- **Server?** Upgrade potential, well-supported distros.
- **Revitalize?** Choose well-supported distros. Don't expect miracles.
- **Friends/Family?** Reliability and easy support are key.

# Architectures and Support

## The Bare Essentials

- [Kernel Support](https://en.wikipedia.org/wiki/List_of_Linux-supported_computer_architectures) for your architecture 

- Drivers for your components, peripherals (ISA bus, wifi, video...)

- Programs to run (a "userland" usually provided by a distribution)

- Some way to install Linux (CD? SD Card? Bootable flash drive?)

- Some way to boot Linux

## CPU Architecture

Different CPUs require different machine code to run. A CPU type (and
sometimes other built-in components) define a *CPU Architecture*

Most common/well-supported:

- 64-bit Intel/AMD (x86_64 / amd64) 
- 64-bit ARM (aarch64)
- 32-bit Intel/AMD (i386, i686)

More info: <https://puppylinux.com/arch.html>

More info: [RISC vs
CISC](https://mobile.twitter.com/kamilkazani/status/1500521868121587718)

. . .

(Sidenote: This is why FLOSS matters)


## 32-bit vs 64-bit

- Technically: how many bits used by the CPU natively (the *word size*)

- In practice: how much RAM a computer supports. 32-bit: 4.3GB (sort
of). 64-bit: lots. 

- 32-bit: Raspberry Pi pre 2.1, Intel/AMD up to Pentium 4

- 64-bit: Raspberry Pi 3+, Intel/AMD from Core 2/Athlon onwards

# Unsolicited Advice


## Is Virtual Linux Good Enough?

- Windows/MacOS/Linux: Virtualbox

- Android: [Termux](https://termux.com)? [Linux
Deploy](https://github.com/meefik/linuxdeploy)?

- iOS: [https://ish.app](iSH)? 

- Windows 10+: Windows Subsystem for Linux (WSL) 

- MacOS: Homebrew (not Linux, but close enough)

- ChromeOS:
[Crostini](https://support.google.com/chromebook/answer/9145439)? 

## Supporting friends/family

- Install the distro you are most familiar with

- Set up remote support tools (VNC, Jitsi, Teamviewer (ugh), NX,
  dwservice.net)

- User experience matters!

- Hardware: desktops and laptops (not tablets, phones)

## Bottlenecks for Old Computers

1. RAM

2. CPU power

3. Wifi support

4. Graphics support

5. Other driver support


## Distros to consider

- The one you are familiar with and can support.

- The ones that support your intended hardware well.

## Lighter distros

- <https://alpinelinux.org/downloads/>

- <http://tinycorelinux.net/downloads.html>

## Weird architecture distros

- <https://debian.org/ports> : watch out for proprietary drivers
(graphics, wifi)

- <https://alpinelinux.org/downloads/> 

- <https://netbsd.org/ports/> : Not Linux, not great for desktops?

## Getting Help

What advice to trust?

- Stack Exchange, obviously (but mind the age of the answers)

- <https://wiki.archlinux.org>

- Reddit (yes, really)

- Friends, community members (like KWLUG?)

- Blog posts by nerds

## Stay safe!

- Avoid old distros!

- Old hardware can have bugs (eg
  [Spectre](https://meltdownattack.com/))

# Misadventures

## The Bare Essentials, Revisited

- [Kernel Support](https://en.wikipedia.org/wiki/List_of_Linux-supported_computer_architectures) for your architecture 

- Drivers for your components, peripherals (ISA bus, wifi, video...)

- Programs to run (a "userland" usually provided by a distribution)

- Some way to install Linux (CD? SD Card? Bootable flash drive?)

- Some way to boot Linux

## Kernel Support

- Idea: Install Linux on an [ALIX
  board](https://www.pcengines.ch/alix2d3.htm) (retired from pfSense). It has an
AMD Geode (i586-class) CPU.

- Reality: Debian [dropped
support](https://lists.debian.org/debian-devel-announce/2016/05/msg00001.html)
for Pentium 1 and earlier CPUs in 2016.

- Reality: Linux [dropped support for 80386
CPUs](https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=743aa456c1834f76982af44e8b71d1a0b2a82e21)
in 2012 (kernel 3.8).

- Maybe OpenWRT or NetBSD would work, but is it worth it?

## Driver Support

- Idea: Use a [Pine64 Quartz64](https://www.pine64.org/quartz64a/)
computer as my next desktop. 

- Reality: The ARM64 CPU is supported, but there are still [incomplete
drivers](https://wiki.pine64.org/wiki/Quartz64_Development) in the
kernel.

## Driver Support 2

- Idea: Jason wants to use his Apple Silicon Mac Mini

- Reality: He is waiting
  for Asahi Linux
  to release so he gets [driver support](https://asahilinux.org/about/)


# Finishing Up

## Future Talk Ideas

- Weird devices that run Linux
- Linux Installations [in the
  Wild](https://old.reddit.com/r/WildLinuxAppears/)
- Why exactly can't you install Linux on arbitrary Android devices?
- Why aren't Android drivers in the Linux tree?
- What distros are best for specific purposes?
- What best practices are there for supporting friends/family?

## Questions and Conversation

- What else do you want to know about installing Linux?
- What other tips and advice do you have?
- What was unclear?

# The End

## Building this presentation

```
pandoc -t revealjs 2022-03-07-install-linux.md -o \
  2022-03-07-install-linux.html --standalone -V theme=night
```
